@@ -20,4 +20,4 @@ class InheritYaw(XMLBoolean):
     _TYPE = 'sdf'
 
     def __init__(self, default=False):
-        XMLBoolean.__init__(self, default)
+        super(InheritYaw, self).__init__(default)
