@@ -145,14 +145,26 @@ class SimulationModel(Entity):
     def link_names(self):
         return list(self._links.keys())
 
+    @property
+    def n_links(self):
+        return len(self._links)
+
     @property
     def joints(self):
         return self._joints
 
+    @property
+    def n_joints(self):
+        return len(self._joints)
+
     @property
     def models(self):
         return self._models
 
+    @property
+    def n_models(self):
+        return len(self._models)
+
     @property
     def model_names(self):
         return list(self._models.keys())
@@ -1397,7 +1409,7 @@ class SimulationModel(Entity):
     def from_gazebo_model(name):
         from . import get_gazebo_model_sdf, is_gazebo_model
         if name == 'ground_plane' and not is_gazebo_model('ground_plane'):
-            from ..generators.components import GroundPlane
+            from ..simulation.components import GroundPlane
             return GroundPlane()
         else:
             PCG_ROOT_LOGGER.info(
